% This function generates the hypothetical genes (False Positives) of Gene
% Mark gene predictions (HGMGL) and Glimmer gene predictions (HGGL).
% HGMGL: Hypothetical GeneMark Gene Locations
% HGGL: Hypothetical Glimmer Gene Locations.
% AGL: Actual Gene Locations.
% GGL: Glimmer Gene Locations.
% GMGL: GeneMark Gene Locations.

function [HGMGL,HGGL] = Hypothetical(AGL,GGL,GMGL)
clc, close all;
% Generate the False Positives of GMGL
for i = 1:length(GMGL)
    i
    for j = 1:length(AGL)
        if (GMGL{i,2} == AGL{j,2})&(GMGL{i,3} == AGL{j,3}), 
            x{i,1} = GMGL{i,1};
            x{i,2} = GMGL{i,2};
            x{i,3} = GMGL{i,3};
            break;
        end
    end
end


k = 1;
for i = 1:length(x)
    if isempty(x{i,1}),
        HGMGL{k,1} = k;
        HGMGL{k,2} = GMGL{i,2};
        HGMGL{k,3} = GMGL{i,3};
        HGMGL{k,4} = GMGL{i,4};
        HGMGL{k,5} = GMGL{i,5};
        HGMGL{k,6} = GMGL{i,6};
        HGMGL{k,7} = GMGL{i,7};
        k = k + 1;
    end
end
%--------------------------------------------------------------------------
% Generate the False Positives of GGL
clear x;
for i = 1:length(GGL)
    i
    for j = 1:length(AGL)
        if (GGL{i,2} == AGL{j,2})&(GGL{i,3} == AGL{j,3}), 
            x{i,1} = GGL{i,1};
            x{i,2} = GGL{i,2};
            x{i,3} = GGL{i,3};
            break;
        end
    end
end

k = 1;
for i = 1:length(x)
    if isempty(x{i,1}),
        HGGL{k,1} = k;
        HGGL{k,2} = GGL{i,2};
        HGGL{k,3} = GGL{i,3};
        HGGL{k,4} = GGL{i,4};
        HGGL{k,5} = GGL{i,5};
        HGGL{k,6} = GGL{i,6};
        HGGL{k,7} = GGL{i,7};
        HGGL{k,8} = GGL{i,8};
        k = k + 1;
    end
end
%--------------------------------------------------------------------------